/*
X310Demo.c: Demo program for X310

Compiler: BC++ 3.1
          Turbo C ++ 1.01(3.01)
          
Compile mode: large

Project: X310Demo.c
         ..\..\lib\7188xbl.lib
         ..\..\lib\XBoard\X310.lib

Hardware: 7188XB + X310

[May/21/2002] by Kevin
[May/20/2005] by Liam
[05/July/2005] by Liam
[Dec 23, 2010] by Nicholas
*/
/************************************************************************/
/*  X310:   2 channel 12-Bit A/D (Analog input)                         */
/*              ch0: 0~20mA                                             */
/*              ch1: 0~10V                                              */
/*          2 channel 12-Bit D/A (Analog output)0.0~10.0V               */
/*          3 channel D/I                                               */
/*          3 channel D/O                                               */
/************************************************************************/
                                                              
/************************************************************************/
/*  [Software specific]                                                 */
/*      Input/Output range: 0mA       20mA  +0.0V      +10.0V           */
/*      Decimal integer:    0         4095  0          4095             */
/*      Hexadecimal:        000       FFF   000        FFF              */
/*                                                                      */
/*      [A/D]                                                           */
/*      sampling rate:  1800 data/sec (with floating convertion)        */
/*      Accuracy==>     Typical: +- 1 LSB (+/- 2.4 mV) (+/- 4.9 uA)     */
/*                      Maximum: +- 2 LSB (+/- 4.8 mV) (+/- 9.8 uA)     */
/*      [D/A]                                                           */
/*      thoughput:  1300 data/sec (with floating convertion)            */
/*      Accuracy==>     Typical: +- 1 LSB (+/- 2.4 mV)                  */
/*                      Maximum: +- 2 LSB (+/- 4.8 mV)                  */
/*      [D/O]                                                           */
/*      throughput: can generates 2KHz square wave signals.             */
/************************************************************************/

/************************************************************************/
/*  [Caution]                                                           */
/*      The block 7 first 16 bytes of EEPROM on X board is used to      */
/*      store A/D & D/A calibration settings. When you use the          */
/*      EEPROM on X board, don't overwrite it.                          */
/************************************************************************/

#include <stdio.h>
#include "..\..\lib\7188xb.h"
#include "..\..\lib\XBoard\X310.h"

void main(void)
{
    int iRet, iAction, j, quit;
    int iValue, iInChannel, iDIValue, iOutChannel, iDOValue, iStatus;
    float fValue;
    
    InitLib();
    X310_Init();    //Initialize the X310
    
    Puts("\r\nDemo program for 7188XB + X310\r\n");
        
    while(iAction!=10)
    {
        iAction=0;
        quit=0;
        
        Puts("\r\n");
        Puts("1) Reads setting from EEPROM\r\n");
        Puts("2) A/D (Analog input)\r\n");
        Puts("3) D/A (Analog output)\r\n");
        Puts("4) Read DI (all channels)\r\n");
        Puts("5) Read DI (one channel)\r\n");
        Puts("6) Write DO (all channels)\r\n");
        Puts("7) Write DO (one channel)\r\n");
        Puts("8) DO Readback (all channels)\r\n");
        Puts("9) DO Readback (one channel)\r\n");
        Puts("\r\n");
        Puts("10) Quits demo program\r\n\r\n");
        Puts("Choose an option and press [Enter]:");
        Scanf("%d", &iAction);
        Puts("\r\n");
    
        switch(iAction)
        {
            // Reads settings from EEPROM(on X board)
            case 1:
                iValue=X310_Init();
                if((iValue&0x1)==0)
                    Print("EEPROM A/D Gain   (Ch0) ==> [%+8.6f]\r\n", X310_fAD_Gain[0]); 
                else
                    Print("No setting in EEPROM, A/D Gain   (Ch0) ==> %+8.6f\r\n", X310_fAD_Gain[0]);
            
                if((iValue&0x2)==0)
                    Print("EEPROM A/D Offset (Ch0) ==> [%+8.6f]\n\r", X310_fAD_Offset[0]);
                else
                    Print("No setting in EEPROM, A/D Offset (Ch0) ==> %+8.6f\r\n", X310_fAD_Offset[0]);

                if((iValue&0x10)==0)
                    Print("EEPROM A/D Gain   (Ch1) ==> [%+8.6f]\n\r", X310_fAD_Gain[1]); 
                else
                    Print("No setting in EEPROM, A/D Gain   (Ch0) ==> %+8.6f\r\n", X310_fAD_Gain[1]);
            
                if((iValue&0x20)==0)
                    Print("EEPROM A/D Offset (Ch1) ==> [%+8.6f]\r\n",X310_fAD_Offset[1]);
                else
                    Print("No setting in EEPROM, A/D Offset (Ch0) ==> %+8.6f\r\n", X310_fAD_Offset[1]);
                
                Puts("\r\n");
                if((iValue&0x4)==0)
                    Print("EEPROM D/A Gain   (Ch0) ==> [%+8.6f]\r\n",X310_fAD_Gain[0]); 
                else
                    Print("No setting in EEPROM, D/A Gain   (Ch0) ==> %+8.6f\r\n", X310_fDA_Gain[0]);
            
                if((iValue&0x8)==0)
                    Print("EEPROM D/A Offset (Ch0) ==> [%+8.6f]\r\n", X310_fDA_Offset[0]);
                else
                    Print("No setting in EEPROM, D/A Offset (Ch0) ==> %+8.6f\r\n", X310_fDA_Offset[0]);

                if((iValue&0x40)==0)
                    Print("EEPROM D/A Gain   (Ch1) ==> [%+8.6f]\r\n", X310_fAD_Gain[0]); 
                else
                    Print("No setting in EEPROM, D/A Gain   (Ch0) ==> %+8.6f\r\n", X310_fDA_Gain[1]);
            
                if((iValue&0x80)==0)
                    Print("EEPROM D/A Offset (Ch1) ==> [%+8.6f]\n\r", X310_fDA_Offset[1]);
                else
                    Print("No setting in EEPROM, D/A Offset (Ch0) ==> %+8.6f\r\n", X310_fDA_Offset[1]);
                    
                Puts("\r\n");
            break;
            // A/D (Analog input)
            case 2:
                Puts("Channel (0 ~ 1): ");
                Scanf("%d", &iInChannel);
                
                if(iInChannel>1)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                fValue=X310_AnalogIn(iInChannel);
                if(iInChannel==0)
                    Print("AI[%d]= %6.4f mA\r\n", iInChannel, fValue);
                else 
                    Print("AI[%d]= %6.4f V\r\n", iInChannel, fValue);
            break;
            // D/A (Analog output)
            case 3:
                Puts("Channel (0 ~ 1): ");
                Scanf("%d", &iOutChannel);
                
                Puts("Voltage (0.0 ~ +10.0): ");
                Scanf("%f", &fValue);
                
                X310_AnalogOut(iOutChannel, fValue);
                Print("AO[%d]  %5.3fV OK.\r\n", iOutChannel, fValue);
            break;
            // Read DI (all channels)
            case 4:
                iDIValue=X310_Read_All_DI();
                
                Print("Input value=> 0x%02x\r\n\r\n", iDIValue);
            break;
            // Read DI (one channel)
            case 5:
                Print("Please select inport channel(0~2): ");
                Scanf("%d", &iInChannel);
                
                if(iInChannel>2)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                iDIValue=X310_Read_One_DI(iInChannel);
                
                if(iDIValue)
                    Print("Channel %d ==> OFF\r\n\r\n", iInChannel);
                else
                    Print("Channel %d ==> ON\r\n\r\n", iInChannel);
            break;
            // Write DO (all channels)
            case 6:
                Print("Please input Output value(0 ~ 0x07): ");
                Scanf("%x", &iDOValue);
                
                X310_Write_All_DO(iDOValue);

                Print("Output value=> 0x%02x\r\n\r\n", iDOValue);
            break;
            // Write DO (one channel)
            case 7:
                Print("Please select outport channel(0~2) and status(0:OFF, 1:ON)\n\r");
                Print("Channel number and status:");
                
                Scanf("%d %d", &iOutChannel, &iStatus);
                
                if(iOutChannel>2)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                X310_Write_One_DO(iOutChannel, iStatus);
                                
                Print("Channel %d ==> %s\r\n\r\n", iOutChannel, (iStatus>=1)?"ON":"OFF");
            break;
            // Read DO (all channels)
            case 8:
                iDOValue=X310_Read_All_DO();
                
                Print("Digital Output ReadBack=> 0x%02x\r\n\r\n", iDOValue);
            break;
            // Read DO (one channels)
            case 9:
                Print("Please select outport channel(0~2): ");
                Scanf("%d", &iOutChannel);
                
                if(iOutChannel>2)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                iRet=X310_Read_One_DO(iOutChannel);
                 
                if(iRet)
                    Print("Channel %d ==> ON\r\n\r\n", iOutChannel);
                else
                    Print("Channel %d ==> OFF\r\n\r\n", iOutChannel);
            break;
            case 10:
            default:
                quit=1;
            break;
        }
        if(!quit)
        {
            Puts("Press any key to continue...\n\r");
            Getch();
        }
    }
}
