/*
X203Demo.c: Demo program for X203

Compiler: MSC 6.0
          MSVC 1.52
          
Compile mode: large

Project: X203Demo.c
         ..\..\lib\7188xbl.lib
         ..\..\lib\XBoard\X203.lib
         
Hardware: 7188XB + X203

[08/July/2005] by Liam
*/
/********************************************************************/
/*   X203: 2 channel 12-Bit A/D (Analog input)            0-20mA    */
/*     2 channel D/I                                                */
/*     6 channel D/O                                                */
/********************************************************************/
/********************************************************************/
/*  [Software specific]                                             */
/*      Input/Output range:      0.0mA    10mA      20mA            */
/*      Decimal integer:         000      2047      4095            */
/*      Hexadecimal:             0x000    0x800     0xFFF           */
/*                                                                  */
/*      [A/D]                                                       */
/*      sampling rate:  1800 data/sec (with floating convertion)    */
/*      Accuracy==>     Maximum: +/- 0.05mA                         */
/*      [D/O]                                                       */
/*      throughput: can generates 2KHz square wave signals.         */
/********************************************************************/
/********************************************************************/
/*  [Caution]                                                       */
/*      The block 7 first 16 bytes of EEPROM on X board is used to  */
/*      store A/D & D/A calibration settings. When you use the      */
/*      EEPROM on X board, don't overwrite it.                      */
/********************************************************************/

#include <stdio.h>
#include "..\..\lib\7188xb.h"
#include "..\..\lib\xboard\X203.h"

void main(void)
{
    int iRet, iAction, j, quit;
    int iValue, iInChannel, iDIValue, iOutChannel, iDOValue, iStatus;
    float fValue;
    char buf[100];
        
    InitLib();
    X203_Init();    //Initialize the X203
    
    Puts("\r\nDemo program for 7188XB + X203\r\n");
    
    while(iAction!=9)
    {
        iAction=0;
        quit=0;
        
        Puts("\r\n");
        Puts("1) Reads setting from EEPROM\r\n");
        Puts("2) A/D (Analog input)\r\n");
        Puts("3) Read DI (all channels)\r\n");
        Puts("4) Read DI (one channel)\r\n");
        Puts("5) Write DO (all channels)\r\n");
        Puts("6) Write DO (one channel)\r\n");
        Puts("7) DO Readback (all channels)\r\n");
        Puts("8) DO Readback (one channel)\r\n");
        Puts("\r\n");
        Puts("9) Quits demo program\r\n\r\n");
        Puts("Choose an option and press [Enter]:");
        LineInput(buf, 99);
        sscanf(buf, "%d", &iAction);
        Puts("\r\n");

        switch(iAction)
        {
            // Reads settings from EEPROM(on X board)
            case 1:
                iValue=X203_Init();
                if((iValue&1)==0)
                    Print("EEPROM A/D Gain ==> [%8.6f]\r\n", fAD_Gain);
                else
                    Print("No setting in EEPROM, A/D Gain ==> %8.6f\r\n", fAD_Gain);
            
                if((iValue&2)==0)
                    Print("EEPROM A/D Offset ==> [%8.6f]\r\n\r\n", fAD_Offset);
                else
                    Print("No setting in EEPROM, A/D Offset ==> %8.6f\r\n\r\n", fAD_Offset);
            break;
            // A/D (Analog input)
            case 2:
                for(j=0; j<2; j++)
                {
                    fValue=X203_AnalogIn(j);
                    Print("AI channel %d = %7.4f mA\r\n", j, fValue);
                }
                Puts("\r\n");
            break;
            // Read DI (all channels)
            case 3:
                iDIValue=X203_Read_All_DI();
                
                Print("Input value=> 0x%02x\r\n\r\n", iDIValue);
            break;
            // Read DI (one channel)
            case 4:
                Print("Please select inport channel(0~1): ");
                LineInput(buf, 99);
                sscanf(buf, "%d", &iInChannel);
                
                if(iInChannel>1)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                iDIValue=X203_Read_One_DI(iInChannel);
                
                if(iDIValue)
                    Print("Channel %d ==> OFF\r\n\r\n", iInChannel);
                else
                    Print("Channel %d ==> ON\r\n\r\n", iInChannel);
            break;
            // Write DO (all channels)
            case 5:
                Print("Please input Output value(0 ~ 0x3f): ");
                LineInput(buf, 99);
                sscanf(buf, "%x", &iDOValue);
                
                X203_Write_All_DO(iDOValue);

                Print("Output value=> 0x%02x\r\n\r\n", iDOValue);
            break;
            // Write DO (one channel)
            case 6:
                Print("Please select outport channel(0~5) and status(0:OFF, 1:ON)\r\n");
                Print("Channel number and status:");
                
                LineInput(buf, 99);
                sscanf(buf, "%d %d", &iOutChannel, &iStatus);
                
                if(iOutChannel>5)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                X203_Write_One_DO(iOutChannel, iStatus);
                                
                Print("Channel %d ==> %s\r\n\r\n", iOutChannel, (iStatus>=1)?"ON":"OFF");
            break;
            // Read DO (all channels)
            case 7:
                iDOValue=X203_Read_All_DO();
                
                Print("Digital Output ReadBack=> 0x%02x\r\n\r\n", iDOValue);
            break;
            // Read DO (one channels)
            case 8:
                Print("Please select outport channel(0~5): ");
                LineInput(buf,99);
                sscanf(buf, "%d", &iOutChannel);
                
                if(iOutChannel>5)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                iRet=X203_Read_One_DO(iOutChannel);
                 
                if(iRet)
                    Print("Channel %d ==> ON\r\n\r\n", iOutChannel);
                else
                    Print("Channel %d ==> OFF\r\n\r\n", iOutChannel);
            break;
            
            case 9:
            default:
                quit=1;
            break;
        }
        if(!quit)
        {
            Puts("Press any key to continue...\r\n");
            Getch();
        }
    }
}

