/*
X308Demo.c: Demo program for X308

Compiler: MSC 6.0
          MSVC 1.52
          
Compile mode: large

Project: X202Demo.c
         ..\..\Lib\7188xbl.lib
         ..\..\Lib\Xboard\X308.lib
         
Hardware: 7188XB + X308

[May/20/2005] by Liam
[08/July/2005] by Liam

/********************************************************************/
/*  X308:   4-Channel 12-Bit A/D (Analog input) 0V ~ +10V           */
/*          6-Channel D/O                                           */
/********************************************************************/
/********************************************************************/
/*  [Software specific]                                             */
/*  Input range:        0.0V    5.0V    5.0V    10.0V               */
/*  Decimal integer:    0       2047    2048     4095               */
/*  Hexadecimal:        000     7FF      800      FFF               */
/*                                                                  */
/*  [A/D]                                                           */
/*  sampling rate:  1800 data/sec (with floating convertion)        */
/*  Resolution ==>  Typical: +/- 1 LSB (+/- 2.4 mV)                 */
/*                  Maximum: +/- 2 LSB (+/- 4.8 mV)                 */
/*  [D/O]                                                           */
/*  throughput: can generates 2KHz square wave signals.             */
/********************************************************************/
/********************************************************************/
/*  [Caution]                                                       */
/*      The EEPROM block 7 on X board is used to                    */
/*      store A/D calibration settings. When you use the            */
/*      EEPROM on X board, don't overwrite it.                      */
/********************************************************************/

#include <stdio.h>
#include "..\..\lib\7188xb.h"
#include "..\..\lib\XBoard\X308.h"

void main(void)
{
    int iRet, iAction, j, quit;
    int iValue, iInChannel, iDIValue, iOutChannel, iDOValue, iStatus;
    float fValue;
    char buf[100];
    
    InitLib();
    X308_Init();    //Initialize the X308
    
    Puts("\r\nDemo program for 7188XB + X308\r\n");

    while(iAction!=7)
    {
        iAction=0;
        quit=0;
        
        Puts("\r\n");
        Puts("Single-Ended 4-Channel\r\n");
        Puts("1) Reads setting from EEPROM\r\n");
        Puts("2) A/D (Analog input)\r\n");
        Puts("3) Write DO (all channels)\r\n");
        Puts("4) Write DO (one channel)\r\n");
        Puts("5) DO Readback (all channels)\r\n");
        Puts("6) DO Readback (one channel)\r\n");
        Puts("\r\n");
        Puts("7) Quits demo program\r\n\r\n");
        Puts("Choose an option and press [Enter]:");
        LineInput(buf, 99);
        sscanf(buf, "%d", &iAction);
        Puts("\r\n");

        switch(iAction)
        {
            // Reads settings from EEPROM(on X board)
            case 1:
                iValue=X308_Init();
                if((iValue&1)==0)
                    Print("EEPROM A/D Gain ==> [%8.6f]\r\n", fAD_Gain);
                else
                    Print("No setting in EEPROM, A/D Gain ==> %8.6f\r\n", fAD_Gain);

                if((iValue&2)==0)
                    Print("EEPROM A/D Offset ==> [%8.6f]\r\n", fAD_Offset);
                else
                    Print("No setting in EEPROM, A/D Offset ==> %8.6f\r\n", fAD_Offset);
                    
                Puts("\r\n");
            break;
            // A/D (Analog input)
            case 2:
                Puts("Please select channel 0 ~ 3: ");
                LineInput(buf, 99);
                sscanf(buf, "%d", &iInChannel);
                
                if(iInChannel>3)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                fValue=X308_AnalogIn(iInChannel);
                Print("AI[%d]= %6.4fV\n\r\n\r", iInChannel, fValue);
            break;
            // Write DO (all channels)
            case 3:
                Print("Please input Output value(0 ~ 0x3f): ");
                LineInput(buf, 99);
                sscanf(buf, "%x", &iDOValue);
                
                X308_Write_All_DO(iDOValue);

                Print("Output value=> 0x%02x\r\n\r\n", iDOValue);
            break;
            // Write DO (one channel)
            case 4:
                Print("Please select outport channel(0~5) and status(0:OFF, 1:ON)\r\n");
                Print("Channel number and status:");
                
                LineInput(buf, 99);
                sscanf(buf, "%d %d", &iOutChannel, &iStatus);
                
                if(iOutChannel>5)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                                
                X308_Write_One_DO(iOutChannel, iStatus);
                                
                Print("Channel %d ==> %s\r\n\r\n", iOutChannel, (iStatus>=1)?"ON":"OFF");
            break;
            // Read DO (all channels)
            case 5:
                iDOValue=X308_Read_All_DO();
                
                Print("Digital Output ReadBack=> 0x%02x\r\n\r\n", iDOValue);
            break;
            // Read DO (one channels)
            case 6:
                Print("Please select outport channel(0~5): ");
                LineInput(buf,99);
                sscanf(buf, "%d", &iOutChannel);
                
                if(iOutChannel>5)
                {
                    Puts("Unknow Channel Number!!\r\n\r\n");
                    break;
                }
                
                iRet=X308_Read_One_DO(iOutChannel);
                 
                if(iRet)
                    Print("Channel %d ==> ON\r\n\r\n", iOutChannel);
                else
                    Print("Channel %d ==> OFF\r\n\r\n", iOutChannel);
            break;
            
            case 7:
            default:
                quit=1;
            break;
        }
        if(!quit)
        {
            Puts("Press any key to continue...\r\n");
            Getch();
        }
    }
}

