/*
X600Demo.c: Demo program for X600

Compiler: BC++ 3.1
          Turbo C ++ 1.01(3.01) (free from http://community.borland.com/museum)
          
Compile mode: large

Project: X600Demo.c
         ..\..\Lib\7188el.lib
         ..\..\Lib\Xboard\X600.lib
         
Hardware: 7188EX + X600

command for x600.exe(x600demo)
  1."D [page]" --> dump one page data(also dump the 16 bytes spare data.)
    page : 0-15, if not give the page number, it will dump the next page.

    just press ENTER has the same function as "D".

  2."B block" -->   set the block number.
    system will show the message "Do you want erase blcok xxx(HHH)?" must press 'y'('Y') to make sure.

    if want use hex value, please use "0x"+HEX, such as "0x1A".

  3."erase block" --> erase block(one block=16 pages)

  4."F page data" --> fill one page with the data.

  5."T block" --> test block.
    Test function will save the block data first, then erase it, then check the erased data are 0xff or not.
    the write the random data to it and check again, then erase again & write back the saved data.

    "TA" --> test all block.
*/

#include<stdlib.h>
#include<stdio.h>
#include<string.h>
#include<conio.h>
#include<ctype.h>
#include<dos.h>

#if !defined(__TURBOC__) || (__TURBOC__ >= 0x0400)
#include<memory.h>
#else
#include<mem.h>
#endif

#include "..\..\lib\7188xb.h"
#include "..\..\lib\xboard\X600.h"

char maker,device,status;
char buf1[512], buf2[16];

/* --- main program ----------------------------------------------- */

void NewDemo(void);
void main(void)
{
    NewDemo();
}

char Prompt[20]="\r\n[X600]";
char cmd[80];
int cmdlength=0;
int block=0;
int page=0;
unsigned char PageBuf[512+16];
void ShowBlockPage(void)
{
    Print("Block=%d(%03X), Page=%d(%X)", block, block, page, page);
}

void DumpData(void)
{
    int i;
    unsigned char *data=PageBuf;

    ShowBlockPage();
    for(i=0;i<512;i++)
    {
        if(!(i&0x0F)) Print("\r\n%03d(%03X):", i, i);
        Print(" %02X", *data++);
    }
    
    Print("\r\nSpare data are:");
    
    for(i=0; i<16; i++)
    {
        Print(" %02X", *data++);
    }
}

void DumpPage(void)
{
    int tmp;

    if(cmdlength>1 && sscanf(cmd+1, "%i", &tmp))
    {
        if(tmp>=0 && tmp<PageNoPerBlock) page=tmp;
    }
    
    tmp=X600_Read_Page(block, page, PageBuf, PageBuf+512);
    
    if(tmp)
    {
        Print("[Read Page error=%d]",tmp);
    }
    else
    {
        DumpData();
        page++;
        if(page==PageNoPerBlock)
        {
            page=0;
            block++;
            if(block>=MaxBlock) block=0;
        }
    }
}

void ChangeBlock(void)
{
    int tmp;

    if(cmdlength>1 && sscanf(cmd+1, "%i",&tmp))
    {
        if(tmp>=0 && tmp<MaxBlock) block=tmp;
    }
    ShowBlockPage();
}

void EraseBlock(void)
{
    int tmp;
    int key;
    long t;

    if(cmdlength>5 && sscanf(cmd+5, "%i",&tmp))
    {
        if(tmp>=0 && tmp<MaxBlock) block=tmp;
    }
    
    Print("Do you want erase blcok %d(%3X)?", block, block);
    
    key=Getch();
    if(key=='y' || key=='Y')
    {
        t=*TimeTicks;
        Print("\r\nErase blcok %d(%3X)...", block, block);
        X600_WP_FLASH(1);
        key=X600_Erase_FLASH_Block(block);
        if(key)
            Print("\r\nerror code=%d",key);
        else
            Print("Erase success.(%ldms)",*TimeTicks-t);
    }
}

void FillPage(void)
{
    int tmp, data;
    int i, j;
    long t;

    if(cmdlength>1)
    {
        j=sscanf(cmd+1, "%i %i", &tmp, &data);
        if(j>=1)
        { 
            if(tmp>=0 && tmp<PageNoPerBlock)
                page=tmp;
            else
            {
                Print("Page number Error");
                return;
            }
            
            if(j==2)
            {
                Print("Fill page %d with 0x%X(%d)", page, data, data);
                memset(PageBuf, data, 512+16);
            }
            else
            {
                Print("Fill page %d start with 0x%X(%d)", page, page, page);
                for(i=0; i<528; i++)
                    PageBuf[i]=i+page;
            }
            
            t=*TimeTicks;
            X600_WP_FLASH(1);
            
            i=X600_Write_Page(block,page, PageBuf, PageBuf+512);
            if(i)
                Print("[Write error=%d]", i);
            else
                Print("[time=%lu ms]", *TimeTicks-t);
            
            X600_WP_FLASH(0);
        }
    }
    else
        Print("use : F page data\r\nuse 0x for Hex data");
}

unsigned char SavedData[32][512+16];
unsigned char Pattern[512+16];
unsigned TestResult[8192];
int TestOneBlock(int blk)
{   /*
    TEST steps:
        1.save all 16 pages data to buffer
        2.erase the block
        3.check if all data==0xff ?
        4.write test pattern,(generate pattern first.)
        5.read back data and compare with the pattern
        6.erase the block
        7.writye back the saved data
    */
    int tpage,err,i;
    unsigned long errcnt;

    Print("\r\nTest Blcok %d(%X)...", blk, blk);
/* step 1. */
    Print("\r\nBackup data ...");
    for(tpage=0; tpage<PageNoPerBlock; tpage++)
    {
        X600_Read_Page(blk, tpage, SavedData[tpage], SavedData[tpage]+512);
    }
/*step 2. */
    Print("\r\nErase ...");
    X600_WP_FLASH(1);
    err=X600_Erase_FLASH_Block(blk);
    if(err)
    {
        Print("\r\nErase rerror code=%d",err);
        TestResult[blk]|=4;
    }
/* step 3. */
    Print("\r\nErase check...");
    errcnt=0;
    for(tpage=0; tpage<PageNoPerBlock; tpage++)
    {
        X600_Read_Page(blk, tpage, PageBuf, PageBuf+512);
        for(i=0; i<512+16; i++)
        {
            if(PageBuf[i] != 0xff)
            {
                errcnt++;
            }
        }
    }
    
    if(errcnt)
    {
        Print("error count=%lu", errcnt);
        TestResult[blk]|=8;
    }
    else Print("OK");
/* step 4.5. */
    Print("\r\nWrite test pattern & check...");
    errcnt=0;
    srand((unsigned)*TimeTicks);
    
    for(tpage=0; tpage<PageNoPerBlock; tpage++)
    {
        for(i=0;i<512+16;i++)
            Pattern[i]=rand();
            
        X600_Write_Page(blk, tpage, Pattern, Pattern+512);
        X600_Read_Page(blk, tpage, PageBuf, PageBuf+512);
        
        for(i=0;i<512+16;i++)
        {
            if(Pattern[i]!=PageBuf[i])
                errcnt++;
        }
    }
    
    if(errcnt)
    {
        Print("error count=%lu", errcnt);
        TestResult[blk]|=32;
    }
    else Print("OK");
/* step 6. */
    Print("\r\nErase ...");
    err=X600_Erase_FLASH_Block(blk);
    if(err)
    {
        Print("\r\nErase rerror code=%d", err);
        TestResult[blk]|=64;
    }
/* step 7. */
    Print("\r\nRestore the saved data...");
    errcnt=0;
    for(tpage=0; tpage<PageNoPerBlock; tpage++)
    {
        X600_Write_Page(blk, tpage, SavedData[tpage], SavedData[tpage]+512);
        X600_Read_Page(blk, tpage, PageBuf, PageBuf+512);
        
        for(i=0;i<512+16;i++)
        {
            if(SavedData[tpage][i]!=PageBuf[i])
            errcnt++;
        }
    }
    
    if(errcnt)
    {
        Print("error count=%lu", errcnt);
        TestResult[blk]|=128;
    }
    else
        Print("OK");
    
    return 0;
}

void TestBlock(void)
{
    int tmp;
    int key;
    int err=0;
    
    if(cmdlength>=2)
    {
        if(cmd[1]=='a' || cmd[1]=='A')  /* Test all block */
        {
            for(tmp=0; tmp<MaxBlock; tmp++)
            {
                TestResult[tmp]=0;
            }
            
            for(tmp=0; tmp<MaxBlock; tmp++)
            {
                if(TestOneBlock(tmp))
                    break;
            }
            
            for(tmp=0; tmp<MaxBlock; tmp++)
            {
                if(TestResult[tmp])
                {
                    Print("<EB:%d>", tmp);
                    err++;
                }
            }
            
            if(!err)
                Print("\r\nALL OK.");
            else
                Print("\r\n%d errors", err);
        }
        else
        {
            if(sscanf(cmd+1,"%i", &tmp) && (tmp>=0 && tmp<MaxBlock))
            {
                TestOneBlock(tmp);
            }
        }
    }
    else if(cmdlength==1)
        TestOneBlock(block);
}

void ResetFlash(void)
{
    Print("Reset Flash");
    X600_Reset_FLASH();
}

void ShowFlashStatus(void)
{
    Print("Status=%02X", X600_Read_FLASH_Status());
}

void ShowHelp(void)
{
    Puts("quit: quit X600demo.exe\r\n"
        "d [page]: DumpPage(or dump next page)\r\n"
        "b block: change to block\r\n"
        "f page data: Fill Page with data\r\n"
        "t block:Test Block\r\n"
        "TA :Test ALL Block\r\n"
        "erase: Erase Block\r\n"
        "r: reset flash\r\n"
        "s: show Flash status\r\n"
        "h/?: Show help message\r\n"
    );
}

void NewDemo(void)
{   
    int quit=0;
    int size;
    char x;

    InitLib();
    Print("\r\nX600 Demo Program : ");

    Init5DigitLed();
    Show5DigitLedWithDot(1,0);
    Show5DigitLed(3,6);
    Show5DigitLed(4,0);

    size=X600_Init();       /* wBase=0 , 2M or 4M flash */
    if(!size)
    {
        Print("Can not find any X60x board");
        return;
    }
    
    Show5DigitLedWithDot(2,size);
    
    if(size==4)
    {
        Print("Find X600, flash size=%d M bytes\r\n", size);
        Show5DigitLed(5, 0);
        x='0';
    }
    else if(size==8)
    {
        Print("Find X601, flash size=%d M bytes\r\n", size);
        Show5DigitLed(5, 1);
        x='1';
    }
    else if(size==16)
    {
        Print("Find X602, flash size=%d M bytes\r\n", size);
        Show5DigitLed(5, 2);
        x='2';
    }
    else if(size==64)
    {
        Print("Find X603, flash size=%d M bytes\r\n", size);
        Show5DigitLed(5, 3);
        x='3';
    }
    else if(size==128)
    {
        Print("Find X604, flash size=%d M bytes\r\n", size);
        Show5DigitLed(5,4);
        x='4';
    }
    
    sprintf(Prompt, "\r\n[X60%c:%dM]", x, size);
    ShowHelp();
    ShowBlockPage();
    
    while(!quit)
    {
        Puts(Prompt);
        
        cmdlength=LineInput(cmd, 79);
        if(cmdlength)
        {
            if(!stricmp(cmd, "quit"))
                quit=1;
            else if(cmd[0]=='r' || cmd[0]=='R') ResetFlash();
            else if(cmd[0]=='s' || cmd[0]=='S') ShowFlashStatus();
            else if(cmd[0]=='d' || cmd[0]=='D') DumpPage();
            else if(cmd[0]=='b' || cmd[0]=='B') ChangeBlock();
            else if(cmd[0]=='f' || cmd[0]=='F') FillPage();
            else if(cmd[0]=='t' || cmd[0]=='T') TestBlock();
            else if(!strnicmp(cmd,"erase",5)) EraseBlock();
            else if(cmd[0]=='h' || cmd[0]=='H' || cmd[0]=='?') ShowHelp();
            else continue;
        }
        else DumpPage();
    }
}
