/*
X702funsDemo.c: Demo program for X702

Compiler: BC++ 3.1
          Turbo C ++ 1.01(3.01) (free from http://community.borland.com/museum) 
          
Compile mode: large

Project: X702funs Demo.
         ..\..\..\..\lib\7188xbl.lib or 7186EL.LIB or 7188EL.LIB
         ..\..\..\..\lib\XBoard\X702.lib
     
Hardware: 7188XB\7188EX\7186EX + X702

Description:
        Show how to use every function for X702.
        Setting for encode:
             Step1: Set XOR logic
             Step2: Choose encode counting mode => cw/ccw,pulse/dir,(Quadrant)a/b phase
             Step3: Read encode counting value and show status for A/B/Z

[5/Mar/2010] by Vic
*/

/********************************************************************************/
/*  X702:   2-axis encoder counter                          */
/********************************************************************************/


#include <stdlib.h>
#include <dos.h>
#include "..\..\..\..\lib\7188xb.h"
#include "..\..\..\..\lib\XBoard\X702.h"

void Show_ABZ(int);

void main(void)
{
   char data;
   int i,LibVer,ch=2,hwID,LatticeVer,read32bit=0;
   int xor[2],tmpxor,mode[2],tmpmode;
   long EncVal[2];
   unsigned char LibDate;

   InitLib();
   X702_Init();
   
   //Check Hardware is old or new
   hwID=X702_GetHardwareID();
   Print("\nHardware ID is 0x%x",hwID);
   
   //Read lattice version (only for new X702 whose hardware ID is 0x72)
   LatticeVer=X702_GetLatticeVersion();
   if(LatticeVer>0) Print("\nLattice Version=%04x",LatticeVer);
   else Print("\nThe hardware can't use X702_GetLatticeVersion()");
   
   LibVer=X702_GetLibVersion();
   Print("\nLibrary version=%04x",LibVer);
    
   X702_GetLibDate(&LibDate);
   Print("\nLibrary date=%02x",LibDate);
   
   
   for(i=0;i<ch;i++){
      Print("\nxor%d=(0 or 1)?",i+1);
      xor[i]=Getch()-'0'; if(xor[i]) xor[i]=1;
      //Step1: Set XOR logic
      X702_SetXOR(i+1,xor[i]);
try_again:      
      Print("\nmode%d = (1=cw/ccw,2=pulse/dir,3=a/b) ?",i+1);
      mode[i]=Getch()-'0';
      if(mode[i]<1 || mode[i]>3) goto try_again;
      //Step2: Choose encode counting mode => cw/ccw,pulse/dir,(Quadrant)a/b phase
      X702_SetMode(i+1,mode[i]);
   }
   
   for(i=0;i<ch;i++){
      X702_GetMode(i+1,&tmpmode);
      if(tmpmode!=mode[i]){
         Print("\nX702_GetMode() function error(%02X)\n",tmpmode);
         exit(1);
      }
   }
   
   for(i=0;i<ch;i++){
      X702_GetXOR(i+1, &tmpxor);
      if(tmpxor!=xor[i]) {
         Print("\nX702_GetXOR() function error\n");
         exit(1);
      }
   }

   for(;;){
      if(Kbhit()) {
         data=Getch(); 
         if(data=='a') X702_ResetEncoder(1);
         else if(data=='b') X702_ResetEncoder(2);         
         else if(data=='c' && hwID==0x72) read32bit=1;
         else if(data=='d') read32bit=0;
         else return;
      }
      //Step3: Read encode counting value and show status for A/B/Z
      if(read32bit){         
         for(i=0;i<ch;i++){
            X702_Read32BitEncoder(i+1,EncVal+i);
            Print("\nxor%d=%d enc%d=%ld mode%d=%d ",i+1,xor[i],i+1,EncVal[i],i+1,mode[i]);
            Show_ABZ(i+1);
         }
      }
      else{
         for(i=0;i<ch;i++){
            X702_Read24BitEncoder(i+1,EncVal+i);
            Print("\nxor%d=%d enc%d=%ld mode%d=%d ",i+1,xor[i],i+1,EncVal[i],i+1,mode[i]);
            Show_ABZ(i+1);
         }
      }
      
      Print("\n");
      DelayMs(100);
   }

}

void Show_ABZ(int ch)
{
   int index;
   int A,B,Z,ret;       
   
   X702_GetLineStatus(ch,&A,&B,&Z);
   
   X702_GetIndex(ch,&index);
   if(index!=Z) {
      Print("\nX702_GetIndex() function error\n");
      exit(1);
   }
   
   Print("Z%dB%dA%d=%d%d%d ",ch,ch,ch,Z,B,A);
}
